@@ -49,6 +49,7 @@ setClass(
         forecast_years="numericOrNULL",
         backcast_years="numericOrNULL",
         forecast_conf="numeric",
+        forecast_save="character",
         estimate="logical",
         estimate.outofsample="logical",
         check="logical",
@@ -120,6 +121,7 @@ setClass(
         forecast_years=1,
         backcast_years=NULL,
         forecast_conf=.95,
+        forecast_save="ftr",
         estimate=FALSE,
         estimate.outofsample=TRUE,
         check=TRUE,
